<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Block minhabiblioteca is defined here.
 *
 * @package     block_minhabiblioteca
 * @copyright   2022 Thiago Livramento <thiago@adapta.online>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class block_minhabiblioteca extends block_base {

    /**
     * Initializes class member variables.
     */
    public function init() {
        // Needed by Moodle to differentiate between blocks.
        $this->title = get_string('pluginname', 'block_minhabiblioteca');
    }

    /**
     * Returns the block contents.
     *
     * @return stdClass The block contents.
     */
    public function get_content() {
        global $CFG, $USER;

        if ($this->content !== null) {
            return $this->content;
        }

        if (empty($this->instance)) {
            $this->content = '';
            return $this->content;
        }

        $this->content = new stdClass();
        $this->content->items = array();
        $this->content->icons = array();
        $this->content->footer = '';

        $token = get_config('block_minhabiblioteca', 'token');

        $service_url = 'https://integracao.dli.minhabiblioteca.com.br/DigitalLibraryIntegrationService/AuthenticatedUrl';
        $curl = curl_init($service_url);
        $firstname = $USER->firstname;
        $lastname = $USER->lastname;
        $email = $USER->email;
        $curl_post_data = "<?xml version=\"1.0\" encoding=\"utf-8\"?>
            <CreateAuthenticatedUrlRequest
            xmlns=\"http://dli.zbra.com.br\"
            xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\"
            xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\">
            <FirstName>{$firstname}</FirstName>
            <LastName>{$lastname}</LastName>
            <Email>{$email}</Email>
            <CourseId xsi:nil=\"true\"/>
            <Tag xsi:nil=\"true\"/>
            <Isbn xsi:nil=\"true\"/>
            </CreateAuthenticatedUrlRequest>
            ";
        $content_size = strlen($curl_post_data);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, "POST");
        curl_setopt($curl, CURLOPT_HTTPHEADER, array(
                    "Content-Type: application/xml; charset=utf-8",
                    "Host: integracao.dli.minhabiblioteca.com.br",
                    "Content-Length: {$content_size}",
                    "Expect: 100-continue",
                    "Accept-Encoding: gzip, deflate",
                    "Connection: Keep-Alive",
                    "X-DigitalLibraryIntegration-API-Key: {$token}")
                );
        curl_setopt($curl, CURLOPT_POSTFIELDS, $curl_post_data);
        $curl_response = curl_exec($curl);
        if ($curl_response === false) {
            $this->content->text = curl_error($curl);
        } else {
            $xml = new SimpleXMLElement($curl_response);
            $image = html_writer::img($CFG->wwwroot . '/blocks/minhabiblioteca/pix/logo_minha_biblioteca.png', 'Minha Biblioteca', ['class'=>'img-responsive']);
            if ($xml->Success == 'true') {
                $this->content->text = html_writer::link($xml->AuthenticatedUrl, $image);
            } else {
                $this->content->text = $image . $xml->Message;
            }
        }
        curl_close($curl);
        return $this->content;
    }

    /**
     * Defines configuration data.
     *
     * The function is called immediately after init().
     */
    public function specialization() {

        $this->config = get_config('block_minhabiblioteca');

        // Load user defined title and make sure it's never empty.
        /*if (empty($this->config->title)) {
        *    $this->title = get_string('pluginname', 'block_minhabiblioteca');
        *} else {
        *    $this->title = $this->config->title;
        *}
        */
    }

    /**
     * Enables global configuration of the block in settings.php.
     *
     * @return bool True if the global configuration is enabled.
     */
    public function has_config() {
        return true;
    }

    /**
     * Sets the applicable formats for the block.
     *
     * @return string[] Array of pages and permissions.
     */
    public function applicable_formats() {
        return array(
            'all' => true,
        );
    }
}
